@@ -1,6 +1,7 @@
 import sys
 import logging
 import gobject
+import gtk
 import deskbar
 from deskbar.core.GconfStore import GconfStore
 from deskbar.core.ModuleInstaller import ModuleInstaller
@@ -11,6 +12,8 @@ from deskbar.core.DeskbarHistory import DeskbarHistory
 from deskbar.core.ThreadPool import ThreadPool
 import deskbar.interfaces
 
+LOGGER = logging.getLogger(__name__)
+
 class CoreImpl(deskbar.interfaces.Core):
     
     DEFAULT_KEYBINDING = "<Alt>F3"
@@ -37,6 +40,10 @@ class CoreImpl(deskbar.interfaces.Core):
         
         self._module_installer = ModuleInstaller(self._module_loader)
         
+        self._gconf.connect("default-browser-changed", self._on_default_browser_changed)
+        #prevent double notifications
+        self.browser = None
+        
     def run(self):
         """
         Load modules, set keybinding and create L{deskbar.core.ThreadPool.ThreadPool}
@@ -61,8 +68,9 @@ class CoreImpl(deskbar.interfaces.Core):
         
     def _setup_keybinder(self):
         self._keybinder = Keybinder()
-        if (self.get_keybinding() == None):
-            self.set_keybinding( DEFAULT_KEYBINDING )
+        if (self.get_keybinding() == None or gtk.accelerator_parse(self.get_keybinding()) == (0,0)):
+            # Keybinding is not set or invalid, set default keybinding
+            self.set_keybinding( self.DEFAULT_KEYBINDING )
         else:
             self.set_keybinding( self.get_keybinding() )
     
@@ -115,7 +123,7 @@ class CoreImpl(deskbar.interfaces.Core):
     
     def get_use_selection(self):
         return self._gconf.get_use_selection()
-    
+
     def get_clear_entry(self):
         return self._gconf.get_clear_entry()
     
@@ -137,21 +145,30 @@ class CoreImpl(deskbar.interfaces.Core):
     def get_window_height(self):
         return self._gconf.get_window_height()
     
+    def get_window_x(self):      
+        return self._gconf.get_window_x()      
+       
+    def get_window_y(self):      
+        return self._gconf.get_window_y()
+    
     def get_hide_after_action(self):
         return self._gconf.get_hide_after_action()
     
     def get_max_history_items(self):
         return self._gconf.get_max_history_items()
     
+    def get_ui_name(self):
+        return self._gconf.get_ui_name()
+    
     def set_keybinding(self, binding):
         """
         Store keybinding and actually bind it
         """
         self._gconf.set_keybinding(binding)
         if not self._keybinder.bind(binding):
-            logging.error("Keybinding is already in use")
+            LOGGER.error("Keybinding is already in use")
         else:
-            logging.info("Successfully binded Deskbar to %s" % binding)
+            LOGGER.info("Successfully binded Deskbar to %s" % binding)
     
     def set_min_chars(self, number):
         self._gconf.set_min_chars(number)
@@ -161,7 +178,7 @@ class CoreImpl(deskbar.interfaces.Core):
     
     def set_use_selection(self, val):
         self._gconf.set_use_selection(val)
-    
+
     def set_clear_entry(self, val):
         self._gconf.set_clear_entry(val)
     
@@ -183,11 +200,20 @@ class CoreImpl(deskbar.interfaces.Core):
     def set_window_height(self, height):
         self._gconf.set_window_height(height)
     
+    def set_window_x(self, x):      
+        self._gconf.set_window_x(x)      
+       
+    def set_window_y(self, y):      
+        self._gconf.set_window_y(y)
+    
     def set_hide_after_action(self, width):
         self._gconf.set_hide_after_action(width)
     
     def set_max_history_items(self, amount):
         self._gconf.set_max_history_items(amount)
+        
+    def set_ui_name(self, name):
+        self._gconf.set_ui_name(name)
     
     def get_history(self):
         """
@@ -223,6 +249,13 @@ class CoreImpl(deskbar.interfaces.Core):
         else:
             self._module_loader.initialize_module(module)
         self._module_list.increase_bottom_enabled_path()
+
+    def reload_all_modules(self):
+        self._module_list.clear()
+        self._disabled_module_list.clear()
+        LOGGER.info("Reloading all modules")
+        self._module_loader.emit("modules-reloading")
+        self._module_loader.load_all()
     
     def stop_queries(self):
         self._stop_queries = True
@@ -313,14 +346,66 @@ class CoreImpl(deskbar.interfaces.Core):
                 else:
                     current_modules_set.add(mod.__class__.__name__)
         
-        #new_modules = enabled_modules_set - current_modules_set
-        #for mod in new_modules:
-            # FIXME: mod is a str but we need the class here
-            #self._module_loader.initialize_module_async( mod )
+        new_modules = enabled_modules_set - current_modules_set
+        for mod_name in new_modules:
+            iter, index = self._module_list.get_position_from_context(mod_name)
+            self.initialize_module(self._module_list[index][self._module_list.MODULE_CTX_COL])
         
         self.update_modules_priority(enabled_modules)
             
     def forward_query_ready(self, handler, query, matches):
         if query == self._last_query and matches != None and len(matches) > 0 and not self._stop_queries:
             self._emit_query_ready(matches)
-        
\ No newline at end of file
+    
+    def update_gconf(self):
+         # Update the gconf enabled modules settings
+        enabled_modules = [mod.__class__.__name__ for mod in self._module_list if mod.is_enabled()]
+        self.set_enabled_modules(enabled_modules)
+    
+    def _on_default_browser_changed(self, gconfstore, new_browser):
+        new_browser = new_browser.split(" ")[0]
+        
+        if new_browser == "firefox":
+            new_browser = "mozilla"
+        
+        if new_browser == "epiphany":
+            old_browser = "mozilla"
+        elif new_browser == "mozilla":
+            old_browser = "epiphany"
+        else:
+            new_browser = "other"
+        
+        #Sometimes we get false notification events when the browser didn't really change. Ignore them.
+        if self.browser == new_browser:
+            return
+        
+        self.browser = new_browser
+                
+        #create a list of the modules that were enabled for the old browser so that we can enable them for the new browser 
+        enabled_browser_modules = []
+        for module in self._module_list:
+            # Check if the module is related to the old browser.
+            if module.__class__.__module__ == "epiphany" or module.__class__.__module__ == "mozilla":
+                if module.is_enabled() and new_browser != "other":
+                    enabled_browser_modules.append(module.__class__.__name__)
+                self.stop_module(module, async=False)
+                self._module_list.remove_module(module)
+                self._module_loader.emit("module-not-initialized", module)
+        
+        filename = None
+        for module in self._disabled_module_list:
+            if module[1].__module__ == new_browser:
+                if filename is None:
+                    filename = module[1].filename
+                self._disabled_module_list.remove_module(module[1])
+                
+        if filename is not None:
+            self._module_loader.load(filename)
+        
+        for module in enabled_browser_modules:
+            new_module_name = module.replace(old_browser.capitalize(), new_browser.capitalize())
+            new_module = self._module_list.get_module_instance_from_name(new_module_name)
+            # If async is True then self.update_gconf() may be run before the modules were initialized
+            self.initialize_module(new_module, async=False)
+        
+        self.update_gconf()
