@@ -9,6 +9,8 @@ from deskbar.core.GconfStore import GconfStore
 from deskbar.core._userdirs import *
 import deskbar.core.Categories
 
+LOGGER = logging.getLogger(__name__)
+
 ICON_THEME = gtk.icon_theme_get_default()
 factory = gnome.ui.ThumbnailFactory(deskbar.ICON_HEIGHT)
 
@@ -102,7 +104,7 @@ def load_icon(icon, width=deskbar.ICON_HEIGHT, height=deskbar.ICON_HEIGHT):
             try:
                 pixbuf = ICON_THEME.load_icon(icon, width, gtk.ICON_LOOKUP_USE_BUILTIN)
             except Exception, msg2:
-                logging.error('load_icon:Icon Load Error:%s (or %s)' % (msg1, msg2))
+                LOGGER.error('load_icon:Icon Load Error:%s (or %s)' % (msg1, msg2))
                 return ICON_THEME.load_icon("stock_unknown", width, gtk.ICON_LOOKUP_USE_BUILTIN)
                 
     # an icon that is too tall will make the EntryCompletion look funny
