@@ -1,23 +1,26 @@
 from deskbar.handlers.actions.OpenWithApplicationAction import OpenWithApplicationAction
 from gettext import gettext as _
-from os.path import exists
 import gnomevfs
 
 class OpenWithNautilusAction(OpenWithApplicationAction):
+    """
+    Open URI with Nautilus
+    """
     
     NETWORK_URIS = ["http", "ftp", "smb", "sftp"]
     AUDIO_URIS = ["cdda"]
     
     def __init__(self, name, url):
+        """
+        @param url: URL including protocol
+        (e.g. file://, http://, ftp://)
+        """
         OpenWithApplicationAction.__init__(self, name, "nautilus", [url])
         self._url = url
     
     def get_icon(self):
         return "file-manager"
-      
-    def is_valid(self):
-        return exists(self._url)
-        
+    
     def get_verb(self):
         uri_scheme = gnomevfs.get_uri_scheme(self._url)
         
